@@ -7,7 +7,7 @@ from lintian_brush.fixer import (
     report_result,
     LintianIssue,
     )
-from lintian_brush.rules import update_rules
+from debmutate._rules import update_rules
 import os
 
 import re
