@@ -17,10 +17,11 @@
 
 """Helper functions for fixers."""
 
+from collections.abc import MutableMapping
 from debmutate.control import ControlEditor
 from debmutate.deb822 import Deb822
 import sys
-from typing import Optional, Tuple, Union, List, Any
+from typing import Optional, Tuple, Union, List
 
 from . import (
     DEFAULT_MINIMUM_CERTAINTY,
@@ -40,13 +41,17 @@ import os
 class LintianIssue(object):
     """Represents a lintian issue."""
 
+    target: Tuple[str, Optional[str]]
+    info: Optional[Union[str, Tuple[str, ...]]]
+    tag: str
+
     def __init__(
         self,
-        target: Union[Deb822, Tuple[str, str]],
+        target: Union[MutableMapping, Tuple[str, str], str],
         tag: str,
         info: Optional[Union[str, Tuple[str, ...]]] = None,
     ):
-        if isinstance(target, Deb822):
+        if isinstance(target, MutableMapping):
             if "Source" in target:
                 target = ("source", target["Source"])
             elif "Package" in target:
@@ -69,10 +74,21 @@ class LintianIssue(object):
         )
 
     def should_fix(self):
-        return not self.override_exists()
+        if self.override_exists():
+            _overriden_issues.append(self)
+            return False
+        return True
 
     def report_fixed(self):
-        _fixed_lintian_tags.append((self.target, self.tag, self.info))
+        _fixed_lintian_issues.append(self)
+
+    def __str__(self):
+        ret = []
+        if self.target[1] is not None:
+            ret.append(self.target[1] + " ")
+        ret.append(self.target[0])
+        ret.append(": " + self.tag + (' ' + self.info) if self.info else '')
+        return "".join(ret)
 
     def __repr__(self):
         return "%s(target=%r, tag=%r, info=%r)" % (
@@ -83,8 +99,9 @@ class LintianIssue(object):
         )
 
 
-_fixed_lintian_tags: List[Any] = []
+_fixed_lintian_issues: List[LintianIssue] = []
 _present_overrides: Optional[List[LintianOverride]] = None
+_overriden_issues = []
 _tag_renames = None
 
 
@@ -110,8 +127,12 @@ def _override_exists(
     return False
 
 
+def fixed_lintian_tags():
+    return set([issue.tag for issue in _fixed_lintian_issues])
+
+
 def fixed_lintian_tag(
-    target: Union[Deb822, Tuple[str, str]],
+    target: Union[MutableMapping, Tuple[str, str], str],
     tag: str,
     info: Optional[Union[str, Tuple[str, ...]]] = None,
 ):
@@ -119,15 +140,12 @@ def fixed_lintian_tag(
     LintianIssue(target, tag, info).report_fixed()
 
 
-def fixed_lintian_tags():
-    return set([tag for (target, tag, info) in _fixed_lintian_tags])
-
-
 def reset() -> None:
     """Reset any global state that may exist."""
-    global _fixed_lintian_tags, _present_overrides
-    _fixed_lintian_tags = []
+    global _fixed_lintian_issues, _present_overrides, _overriden_issues
+    _fixed_lintian_issues = []
     _present_overrides = None
+    _overriden_issues = []
 
 
 def report_result(description=None, certainty=None, patch_name=None):
@@ -135,7 +153,6 @@ def report_result(description=None, certainty=None, patch_name=None):
 
     Args:
       description: Description of the fix
-      fixed_lintian_tags: Set of fixed lintian tags
       certainty: Certainty of the fix
       patch_name: Suggested patch name, if there are upstream changes
     """
@@ -143,9 +160,14 @@ def report_result(description=None, certainty=None, patch_name=None):
         print(description)
     if certainty:
         print("Certainty: %s" % certainty)
-    fixed_lintian_tags = set([tag for (target, tag, info) in _fixed_lintian_tags])
+    fixed_lintian_tags = set(
+        [issue.tag for issue in _fixed_lintian_issues])
     if fixed_lintian_tags:
         print("Fixed-Lintian-Tags: %s" % ", ".join(sorted(fixed_lintian_tags)))
+    if _overriden_issues:
+        print("Overridden-Lintian-Issues:")
+        for issue in _overriden_issues:
+            print(' ' + str(issue))
     if patch_name:
         print("Patch-Name: %s" % patch_name)
     reset()
@@ -157,9 +179,15 @@ def net_access_allowed():
 
 
 def compat_release():
+    """Codename of oldest release to stay compatible with."""
     return os.environ.get("COMPAT_RELEASE", "sid")
 
 
+def upgrade_release():
+    """Codename of oldest release to allow upgrading from."""
+    return os.environ.get("UPGRADE_RELEASE", "oldstable")
+
+
 def current_package_version():
     return Version(os.environ["CURRENT_VERSION"])
 
@@ -203,4 +231,12 @@ def vendor():
             return c['Vendor']
 
 
-control = ControlEditor()
+if os.path.exists('debian/debcargo.toml'):
+    from debmutate.debcargo import DebcargoControlShimEditor, DebcargoEditor
+
+    try:
+        control = DebcargoControlShimEditor.from_debian_dir('debian')
+    except AttributeError:
+        control = DebcargoControlShimEditor(DebcargoEditor())
+else:
+    control = ControlEditor()
