@@ -23,12 +23,8 @@ import logging
 import os
 
 from breezy.commit import PointlessCommit
-from breezy.trace import note
 
-try:
-    from debmutate.debhelper import MaintscriptEditor
-except ImportError:
-    MaintscriptEditor = None
+from debmutate.debhelper import MaintscriptEditor
 
 
 from debian.changelog import Version
@@ -46,7 +42,8 @@ from debmutate.reformatting import (
 )
 
 from .changelog import add_changelog_entry
-from . import get_committer
+from . import get_committer, control_files_in_root, NotDebianPackage
+from .debhelper import drop_obsolete_maintscript_entries
 
 
 _changelog_policy_noted = False
@@ -59,31 +56,10 @@ def _note_changelog_policy(policy, msg):
             extra = "Specify --no-update-changelog to override."
         else:
             extra = "Specify --update-changelog to override."
-        note("%s %s", msg, extra)
+        logging.info("%s %s", msg, extra)
     _changelog_policy_noted = True
 
 
-def drop_old_maintscript(editor, package_name, upgrade_release):
-    remove = []
-    for i, entry in enumerate(list(editor.lines)):
-        if isinstance(entry, str):
-            continue
-        prior_version = getattr(entry, "prior_version", None)
-        if prior_version is None:
-            continue
-        package = entry.package or package_name
-        compat_version = package_version(package, upgrade_release)
-        if compat_version is None:
-            continue
-        if compat_version > prior_version:
-            remove.append(i)
-    removed = []
-    for i in reversed(remove):
-        removed.append(editor.lines[i])
-        del editor.lines[i]
-    return removed
-
-
 def depends_obsolete(latest_version, kind, req_version):
     req_version = Version(req_version)
     if kind == ">=":
@@ -118,9 +94,9 @@ async def _package_version(source, release):
     return None
 
 
-def package_version(source, upgrade_release):
+def package_version(source, release):
     loop = asyncio.get_event_loop()
-    return loop.run_until_complete(_package_version(source, upgrade_release))
+    return loop.run_until_complete(_package_version(source, release))
 
 
 def drop_obsolete_depends(entry, upgrade_release):
@@ -155,26 +131,9 @@ def drop_obsolete_conflicts(entry, upgrade_release):
 
 
 def update_depends(base, field, upgrade_release):
-    try:
-        old_contents = base[field]
-    except KeyError:
-        return []
-
-    changed = []
-    newrelations = []
-    for ws1, oldrelation, ws2 in parse_relations(old_contents):
-        relation, dropped = drop_obsolete_depends(oldrelation, upgrade_release)
-        changed.extend([d.name for d in dropped])
-        if relation:
-            newrelations.append((ws1, relation, ws2))
-
-    if changed:
-        if relations_empty(newrelations):
-            del base[field]
-        else:
-            base[field] = format_relations(newrelations)
-        return changed
-    return []
+    return filter_relations(
+        base, field,
+        lambda oldrelation: drop_obsolete_depends(oldrelation, upgrade_release))
 
 
 def relations_empty(rels):
@@ -184,18 +143,25 @@ def relations_empty(rels):
     return True
 
 
-def update_conflicts(base, field, upgrade_release):
+def filter_relations(base, field, cb):
     try:
         old_contents = base[field]
     except KeyError:
         return []
 
-    changed = []
+    oldrelations = parse_relations(old_contents)
     newrelations = []
-    for ws1, oldrelation, ws2 in parse_relations(old_contents):
-        relation, dropped = drop_obsolete_conflicts(oldrelation, upgrade_release)
+
+    changed = []
+    for i, (ws1, oldrelation, ws2) in enumerate(oldrelations):
+        relation, dropped = cb(oldrelation)
         changed.extend([d.name for d in dropped])
-        newrelations.append((ws1, relation, ws2))
+        if relation:
+            newrelations.append((ws1, relation, ws2))
+        elif i == 0 and len(oldrelations) > 1:
+            # If the first item is removed, then copy the spacing to the next
+            # item
+            oldrelations[1] = (ws1, oldrelations[1][1], ws2)
 
     if changed:
         if relations_empty(newrelations):
@@ -206,18 +172,24 @@ def update_conflicts(base, field, upgrade_release):
     return []
 
 
-def drop_old_source_relations(source, upgrade_release):
+def update_conflicts(base, field, upgrade_release):
+    return filter_relations(
+        base, field,
+        lambda oldrelation: drop_obsolete_conflicts(oldrelation, upgrade_release))
+
+
+def drop_old_source_relations(source, compat_release):
     ret = []
     for field in [
         "Build-Depends",
         "Build-Depends-Indep",
         "Build-Depends-Arch",
     ]:
-        packages = update_depends(source, field, upgrade_release)
+        packages = update_depends(source, field, compat_release)
         if packages:
             ret.append((field, packages))
     for field in ["Build-Conflicts", "Build-Conflicts-Indep", "Build-Conflicts-Arch"]:
-        packages = update_conflicts(source, field, upgrade_release)
+        packages = update_conflicts(source, field, compat_release)
         if packages:
             ret.append((field, packages))
     return ret
@@ -238,7 +210,7 @@ def drop_old_binary_relations(binary, upgrade_release):
     return ret
 
 
-def drop_old_relations(editor, upgrade_release):
+def drop_old_relations(editor, compat_release, upgrade_release):
     dropped = []
     source_dropped = []
     try:
@@ -251,7 +223,7 @@ def drop_old_relations(editor, upgrade_release):
     else:
         uses_cdbs = False
     if not uses_cdbs:
-        source_dropped.extend(drop_old_source_relations(editor.source, upgrade_release))
+        source_dropped.extend(drop_old_source_relations(editor.source, compat_release))
     if source_dropped:
         dropped.append((None, source_dropped))
 
@@ -263,15 +235,18 @@ def drop_old_relations(editor, upgrade_release):
     return dropped
 
 
-def update_maintscripts(wt, path, package, upgrade_release):
+def update_maintscripts(wt, subpath, package, upgrade_release, allow_reformatting=False):
     ret = []
-    for entry in os.scandir(wt.abspath(os.path.join(path, "debian"))):
+    for entry in os.scandir(wt.abspath(os.path.join(subpath))):
         if not (entry.name == "maintscript" or entry.name.endswith(".maintscript")):
             continue
-        with MaintscriptEditor(entry.path) as editor:
-            removed = drop_old_maintscript(editor, package, upgrade_release)
+        with MaintscriptEditor(entry.path, allow_reformatting=allow_reformatting) as editor:
+            def can_drop(p, v):
+                compat_version = package_version(p or package, upgrade_release)
+                return compat_version is not None and compat_version > v
+            removed = drop_obsolete_maintscript_entries(editor, can_drop)
             if removed:
-                ret.append((os.path.join(path, "debian", entry.name), removed))
+                ret.append((os.path.join(subpath, entry.name), removed))
     return ret
 
 
@@ -306,27 +281,33 @@ class ScrubObsoleteResult(object):
                         % (field, name_list(packages))
                     )
         if self.maintscript_removed:
+            total_entries = sum(
+                [len(entries) for name, entries in self.maintscript_removed])
             summary.append(
-                "Remove %d maintscript entries." % len(self.maintscript_removed)
+                "Remove %d maintscript entries from %d files." % (
+                    total_entries, len(self.maintscript_removed))
             )
         return summary
 
 
-def _scrub_obsolete(wt, subpath, upgrade_release):
+def _scrub_obsolete(wt, debian_path, compat_release, upgrade_release, allow_reformatting):
     specific_files = []
-    control_path = os.path.join(subpath, "debian/control")
+    control_path = os.path.join(debian_path, "control")
     try:
-        with ControlEditor(wt.abspath(control_path)) as editor:
+        with ControlEditor(
+                wt.abspath(control_path),
+                allow_reformatting=allow_reformatting) as editor:
             specific_files.append(control_path)
             package = editor.source["Source"]
-            control_removed = drop_old_relations(editor, upgrade_release)
+            control_removed = drop_old_relations(editor, compat_release, upgrade_release)
     except FileNotFoundError:
-        if wt.has_filename(os.path.join(subpath, "debian/debcargo.toml")):
-            return ScrubObsoleteResult([], [], [])
-        raise
+        if wt.has_filename(os.path.join(debian_path, "debcargo.toml")):
+            control_removed = []
+        else:
+            raise NotDebianPackage(wt, debian_path)
 
     maintscript_removed = []
-    for path, removed in update_maintscripts(wt, subpath, package, upgrade_release):
+    for path, removed in update_maintscripts(wt, debian_path, package, upgrade_release, allow_reformatting):
         if removed:
             maintscript_removed.append((path, removed))
             specific_files.append(path)
@@ -338,10 +319,16 @@ def _scrub_obsolete(wt, subpath, upgrade_release):
     )
 
 
-def scrub_obsolete(wt, subpath, upgrade_release, update_changelog=None):
+def scrub_obsolete(wt, subpath, compat_release, upgrade_release, update_changelog=None,
+                   allow_reformatting=False):
     from breezy.commit import NullCommitReporter
 
-    result = _scrub_obsolete(wt, subpath, upgrade_release)
+    if control_files_in_root(wt, subpath):
+        debian_path = subpath
+    else:
+        debian_path = os.path.join(subpath, 'debian')
+
+    result = _scrub_obsolete(wt, debian_path, compat_release, upgrade_release, allow_reformatting)
 
     if not result:
         return result
@@ -349,7 +336,7 @@ def scrub_obsolete(wt, subpath, upgrade_release, update_changelog=None):
     specific_files = list(result.specific_files)
     summary = result.itemized()
 
-    changelog_path = os.path.join(subpath, "debian/changelog")
+    changelog_path = os.path.join(debian_path, "changelog")
 
     if update_changelog is None:
         from .detect_gbp_dch import guess_update_changelog
@@ -358,7 +345,7 @@ def scrub_obsolete(wt, subpath, upgrade_release, update_changelog=None):
         with wt.get_file(changelog_path) as f:
             cl = Changelog(f, max_blocks=1)
 
-        dch_guess = guess_update_changelog(wt, subpath, cl)
+        dch_guess = guess_update_changelog(wt, debian_path, cl)
         if dch_guess:
             update_changelog = dch_guess[0]
             _note_changelog_policy(update_changelog, dch_guess[1])
@@ -405,7 +392,6 @@ def main():
     breezy.initialize()
     import breezy.git  # noqa: E402
     import breezy.bzr  # noqa: E402
-    from breezy.trace import note  # note: E402
 
     from . import (
         check_clean_tree,
@@ -428,6 +414,11 @@ def main():
         help="Release to allow upgrading from.",
         default="oldstable",
     )
+    parser.add_argument(
+        '--compat-release',
+        metavar='COMPAT-RELEASE',
+        help="Release to allow building on.",
+        default=None)
     parser.add_argument(
         "--no-update-changelog",
         action="store_false",
@@ -442,6 +433,12 @@ def main():
         help="force updating of the changelog",
         default=None,
     )
+    parser.add_argument(
+        "--allow-reformatting",
+        default=None,
+        action="store_true",
+        help=argparse.SUPPRESS,
+    )
     parser.add_argument(
         "--version", action="version", version="%(prog)s " + version_string
     )
@@ -459,27 +456,30 @@ def main():
 
     wt, subpath = WorkingTree.open_containing(args.directory)
     if args.identity:
-        note(get_committer(wt))
+        logging.info('%s', get_committer(wt))
         return 0
 
     try:
         check_clean_tree(wt, wt.basis_tree(), subpath)
     except PendingChanges:
-        note("%s: Please commit pending changes first.", wt.basedir)
+        logging.info("%s: Please commit pending changes first.", wt.basedir)
         return 1
 
     import distro_info
-
     debian_info = distro_info.DebianDistroInfo()
     upgrade_release = debian_info.codename(args.upgrade_release)
 
-    note("Removing constraints unnecessary since %s", upgrade_release)
-
     if args.debug:
-        logging.basicConfig()
-        logging.getLogger().setLevel(logging.DEBUG)
+        logging.basicConfig(level=logging.DEBUG)
+    else:
+        logging.basicConfig(level=logging.INFO)
 
     update_changelog = args.update_changelog
+    allow_reformatting = args.allow_reformatting
+    if args.compat_release:
+        compat_release = debian_info.codename(args.compat_release)
+    else:
+        compat_release = None
     try:
         cfg = Config.from_workingtree(wt, subpath)
     except FileNotFoundError:
@@ -487,12 +487,32 @@ def main():
     else:
         if update_changelog is None:
             update_changelog = cfg.update_changelog()
+        if allow_reformatting is None:
+            allow_reformatting = cfg.allow_reformatting()
+        if compat_release is None:
+            compat_release = cfg.compat_release()
 
-    result = scrub_obsolete(
-        wt, subpath, upgrade_release, update_changelog=args.update_changelog
-    )
-    if not result:
-        return 0
+    if compat_release is None:
+        compat_release = debian_info.stable()
+
+    logging.info(
+        "Removing run time constraints unnecessary since %s"
+        " and build time constraints unnecessary since %s",
+        upgrade_release, compat_release)
+
+    if allow_reformatting is None:
+        allow_reformatting = False
+
+    try:
+        scrub_obsolete(
+            wt, subpath, compat_release, upgrade_release,
+            update_changelog=args.update_changelog,
+            allow_reformatting=allow_reformatting
+        )
+    except NotDebianPackage:
+        logging.fatal('not a Debian package.')
+        return 1
+    return 0
 
 
 if __name__ == "__main__":
